Crate bevy_trenchbroom_macros

Crate bevy_trenchbroom_macros 

Macros

manifest
Generates a manifest accounting the structure of a folder at compile time. Use like manifest!("folder path from project root").

Attribute Macros

base_class
Base classes don’t appear in-editor, rather they give properties and attributes to their sub-classes (components that require them).
point_class
Point classes don’t have any geometry built in – simply a point in space.
solid_class
Solid classes contain brush geometry.

Derive Macros

FgdType
Any field in quake class components must implement FgdType. Specifically, this macro implements it for unit enums, to create choices properties.